summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--buildtools/autotools/autosubprojectview.cpp2
-rw-r--r--buildtools/qmake/projectconfigurationdlg.cpp16
-rw-r--r--kdevdesigner/designer/project.cpp2
-rw-r--r--languages/cpp/cppimplementationwidget.cpp2
-rw-r--r--languages/cpp/cppnewclassdlg.cpp6
-rw-r--r--languages/cpp/qtdesignercppintegration.cpp2
-rw-r--r--languages/cpp/subclassingdlg.cpp2
-rw-r--r--lib/cppparser/lexer.cpp2
-rw-r--r--lib/widgets/propeditor/pdoublenuminput.h2
-rw-r--r--parts/astyle/astyle_part.cpp2
-rw-r--r--parts/doxygen/doxygenpart.cpp2
-rw-r--r--parts/outputviews/makeactionfilter.cpp4
12 files changed, 22 insertions, 22 deletions
diff --git a/buildtools/autotools/autosubprojectview.cpp b/buildtools/autotools/autosubprojectview.cpp
index 71005417..35747807 100644
--- a/buildtools/autotools/autosubprojectview.cpp
+++ b/buildtools/autotools/autosubprojectview.cpp
@@ -230,7 +230,7 @@ void AutoSubprojectView::initActions()
TQT_SLOT( slotForceReeditSubproject() ), actions, "force-reedit subproject" );
forceReeditSubprojectAction->setWhatsThis(i18n("<qt><b>Force Reedit</b><p>Runs <b>make force-reedit</b> "
"from the directory of the selected subproject.<br>This "
- "recreates makefile (tip: and solves most of .tqmoc related "
+ "recreates makefile (tip: and solves most of .moc related "
"problems)<br>Environment variables and make arguments can "
"be specified in the project settings dialog, "
"<b>Make Options</b> tab.</qt>"));
diff --git a/buildtools/qmake/projectconfigurationdlg.cpp b/buildtools/qmake/projectconfigurationdlg.cpp
index b625f821..e5e80b2e 100644
--- a/buildtools/qmake/projectconfigurationdlg.cpp
+++ b/buildtools/qmake/projectconfigurationdlg.cpp
@@ -109,8 +109,8 @@ ProjectConfigurationDlg::ProjectConfigurationDlg( TQListView *_prjList, TrollPro
TQRegExp( "\\d+(\\.\\d+)?(\\.\\d+)" ), TQT_TQOBJECT(this) ) );
customVariables->setSortColumn(0);
customVariables->setSortOrder(TQt::Ascending);
- tqmocdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
- tqmocdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+ mocdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
+ mocdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
objdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
objdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
rccdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
@@ -603,7 +603,7 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
// intermediate locations
myProjectItem->scope->setEqualOp( "OBJECTS_DIR", TQStringList( objdir_url->url() ) );
myProjectItem->scope->setEqualOp( "UI_DIR", TQStringList( uidir_url->url() ) );
- myProjectItem->scope->setEqualOp( "QMOC_DIR", TQStringList( tqmocdir_url->url() ) );
+ myProjectItem->scope->setEqualOp( "QMOC_DIR", TQStringList( mocdir_url->url() ) );
myProjectItem->scope->setEqualOp( "RCC_DIR", TQStringList( rccdir_url->url() ) );
//CORBA
@@ -974,14 +974,14 @@ void ProjectConfigurationDlg::updateControls()
dir = myProjectItem->scope->variableValues( "QMOC_DIR" ).front();
if( TQFileInfo(dir).isRelative() )
{
- tqmocdir_url->completionObject()->setDir( myProjectItem->scope->projectDir() );
- tqmocdir_url->fileDialog()->setURL( KURL( myProjectItem->scope->projectDir()+"/"+dir ) );
+ mocdir_url->completionObject()->setDir( myProjectItem->scope->projectDir() );
+ mocdir_url->fileDialog()->setURL( KURL( myProjectItem->scope->projectDir()+"/"+dir ) );
}else
{
- tqmocdir_url->completionObject()->setDir( dir );
- tqmocdir_url->fileDialog()->setURL( KURL( dir ) );
+ mocdir_url->completionObject()->setDir( dir );
+ mocdir_url->fileDialog()->setURL( KURL( dir ) );
}
- tqmocdir_url->setURL( dir );
+ mocdir_url->setURL( dir );
dir = myProjectItem->scope->variableValues( "RC_DIR" ).front();
if( TQFileInfo(dir).isRelative() )
{
diff --git a/kdevdesigner/designer/project.cpp b/kdevdesigner/designer/project.cpp
index e14aa5aa..44678dc5 100644
--- a/kdevdesigner/designer/project.cpp
+++ b/kdevdesigner/designer/project.cpp
@@ -691,7 +691,7 @@ void Project::save( bool onlyProjectFile )
contents +=
"unix {\n"
" UI_DIR = .ui\n"
- " TQMOC_DIR = .tqmoc\n"
+ " TQMOC_DIR = .moc\n"
" OBJECTS_DIR = .obj\n"
"}\n";
}
diff --git a/languages/cpp/cppimplementationwidget.cpp b/languages/cpp/cppimplementationwidget.cpp
index 9c3bf466..aeb2ae09 100644
--- a/languages/cpp/cppimplementationwidget.cpp
+++ b/languages/cpp/cppimplementationwidget.cpp
@@ -57,7 +57,7 @@ TQStringList CppImplementationWidget::createClassFiles()
template_cpp.replace( TQRegExp( "\\$CLASSINCLUDE\\$" ), fileNameEdit->text() + ".h" );
template_cpp.replace( TQRegExp( "\\$CLASSNAME\\$" ), classNameEdit->text() );
template_cpp.replace( TQRegExp( "\\$BASECLASSNAME\\$" ), m_baseClassName );
- template_cpp.replace( TQRegExp( "\\$TQMOCINCLUDE\\$" ), fileNameEdit->text() + ".tqmoc" );
+ template_cpp.replace( TQRegExp( "\\$TQMOCINCLUDE\\$" ), fileNameEdit->text() + ".moc" );
template_h = FileTemplate::read( m_part, "h" ) + template_h;
template_cpp = FileTemplate::read( m_part, "cpp" ) + template_cpp;
diff --git a/languages/cpp/cppnewclassdlg.cpp b/languages/cpp/cppnewclassdlg.cpp
index e08188b2..8cd37938 100644
--- a/languages/cpp/cppnewclassdlg.cpp
+++ b/languages/cpp/cppnewclassdlg.cpp
@@ -1820,9 +1820,9 @@ void CppNewClassDialog::ClassGenerator::gen_implementation()
if ( ( dlg.m_part->project() ) && ( childClass || qobject ) && ( dlg.m_part->project() ->options() & KDevProject::UsesAutotoolsBuildSystem ) )
{
- TQString tqmoc = header;
- tqmoc.replace( TQRegExp( "\\..*" ), ".tqmoc" );
- classImpl += "#include \"" + tqmoc + "\"\n";
+ TQString moc = header;
+ moc.replace( TQRegExp( "\\..*" ), ".moc" );
+ classImpl += "#include \"" + moc + "\"\n";
}
if ( dlg.gen_config->reformat_box->isChecked() )
diff --git a/languages/cpp/qtdesignercppintegration.cpp b/languages/cpp/qtdesignercppintegration.cpp
index f61b64e2..32d407a4 100644
--- a/languages/cpp/qtdesignercppintegration.cpp
+++ b/languages/cpp/qtdesignercppintegration.cpp
@@ -158,7 +158,7 @@ void QtDesignerCppIntegration::addFunctionToClass( KInterfaceDesigner::Function
}
else
{
- if ( editIface->textLine( line ).contains( TQRegExp( ".*#include .*\\.tqmoc.*" ) ) )
+ if ( editIface->textLine( line ).contains( TQRegExp( ".*#include .*\\.moc.*" ) ) )
atLine = line;
break;
}
diff --git a/languages/cpp/subclassingdlg.cpp b/languages/cpp/subclassingdlg.cpp
index 6037f010..f4fd085e 100644
--- a/languages/cpp/subclassingdlg.cpp
+++ b/languages/cpp/subclassingdlg.cpp
@@ -476,7 +476,7 @@ void SubclassingDlg::accept()
buffer.replace(TQRegExp("\\$MODULE\\$"),module);
buffer.replace(TQRegExp("\\$FILENAME\\$"),basefilename);
if ( (m_cppSupport->project()) && (m_cppSupport->project()->options() & KDevProject::UsesAutotoolsBuildSystem))
- buffer += "\n#include \"$NEWFILENAMELC$.tqmoc\"\n";
+ buffer += "\n#include \"$NEWFILENAMELC$.moc\"\n";
}
else
loadBuffer(buffer,m_filename+".cpp");
diff --git a/lib/cppparser/lexer.cpp b/lib/cppparser/lexer.cpp
index 687cce08..4863a4a1 100644
--- a/lib/cppparser/lexer.cpp
+++ b/lib/cppparser/lexer.cpp
@@ -1026,7 +1026,7 @@ int Lexer::macroExpression()
}
// *IMPORTANT*
-// please, don't include lexer.tqmoc here, because Lexer isn't a TQObject class!!
+// please, don't include lexer.moc here, because Lexer isn't a TQObject class!!
// if you have problem while recompiling try to remove cppsupport/.deps,
// cppsupport/Makefile.in and rerun automake/autoconf
diff --git a/lib/widgets/propeditor/pdoublenuminput.h b/lib/widgets/propeditor/pdoublenuminput.h
index a26c2b0f..a398c498 100644
--- a/lib/widgets/propeditor/pdoublenuminput.h
+++ b/lib/widgets/propeditor/pdoublenuminput.h
@@ -47,7 +47,7 @@ public:
virtual void setValue(const TQVariant &value, bool emitChange=true);
private slots:
- //because of a bug in tqmoc which doesn't detect conditional slots
+ //because of a bug in moc which doesn't detect conditional slots
//we need them both
void updateProperty(double val);
void updateProperty(int val);
diff --git a/parts/astyle/astyle_part.cpp b/parts/astyle/astyle_part.cpp
index 7cfb6b17..eef40e98 100644
--- a/parts/astyle/astyle_part.cpp
+++ b/parts/astyle/astyle_part.cpp
@@ -36,7 +36,7 @@
static const KDevPluginInfo data("kdevastyle");
namespace {
- const char* defaultFormatExtensions = "*.cpp *.h *.hpp,*.c *.h,*.cxx *.hxx,*.c++ *.h++,*.cc *.hh,*.C *.H,*.diff ,*.inl,*.java,*.tqmoc,*.patch,*.tlh,*.xpm";
+ const char* defaultFormatExtensions = "*.cpp *.h *.hpp,*.c *.h,*.cxx *.hxx,*.c++ *.h++,*.cc *.hh,*.C *.H,*.diff ,*.inl,*.java,*.moc,*.patch,*.tlh,*.xpm";
}
diff --git a/parts/doxygen/doxygenpart.cpp b/parts/doxygen/doxygenpart.cpp
index e04e79da..f267fec9 100644
--- a/parts/doxygen/doxygenpart.cpp
+++ b/parts/doxygen/doxygenpart.cpp
@@ -172,7 +172,7 @@ void DoxygenPart::adjustDoxyfile()
patterns->addValue("*.tlh");
patterns->addValue("*.diff");
patterns->addValue("*.patch");
- patterns->addValue("*.tqmoc");
+ patterns->addValue("*.moc");
patterns->addValue("*.xpm");
patterns->addValue("*.dox");
}
diff --git a/parts/outputviews/makeactionfilter.cpp b/parts/outputviews/makeactionfilter.cpp
index 0058b2e9..5c8e7c6c 100644
--- a/parts/outputviews/makeactionfilter.cpp
+++ b/parts/outputviews/makeactionfilter.cpp
@@ -79,8 +79,8 @@ MakeActionFilter::ActionFormat* MakeActionFilter::actionFormats()
ActionFormat( i18n("built"), 1, 1, "\\[.+%\\] Built target (.*)" ), //cmake
ActionFormat( i18n("generating"), 1, 1, "\\[.+%\\] Generating (.*)" ), //cmake
- //tqmoc and uic
- ActionFormat( i18n("generating"), 1, 2, "/(tqmoc|uic)\\b.*\\s-o\\s([^\\s;]+)"),
+ //moc and uic
+ ActionFormat( i18n("generating"), 1, 2, "/(moc|uic)\\b.*\\s-o\\s([^\\s;]+)"),
ActionFormat( i18n("generating"), 1, 2, "^generating (.*)" ), //unsermake
ActionFormat( i18n("linking"), "libtool", "/bin/sh\\s.*libtool.*--mode=link\\s.*\\s-o\\s([^\\s;]+)", 1 ),